@@ -53,11 +53,17 @@ from .asset_service import (
     OutputResult,
     PartitionSpec,
     PubsubDestination,
+    QueryAssetsOutputConfig,
+    QueryAssetsRequest,
+    QueryAssetsResponse,
+    QueryResult,
     SavedQuery,
     SearchAllIamPoliciesRequest,
     SearchAllIamPoliciesResponse,
     SearchAllResourcesRequest,
     SearchAllResourcesResponse,
+    TableFieldSchema,
+    TableSchema,
     UpdateFeedRequest,
     UpdateSavedQueryRequest,
     ContentType,
@@ -121,11 +127,17 @@ __all__ = (
     "OutputResult",
     "PartitionSpec",
     "PubsubDestination",
+    "QueryAssetsOutputConfig",
+    "QueryAssetsRequest",
+    "QueryAssetsResponse",
+    "QueryResult",
     "SavedQuery",
     "SearchAllIamPoliciesRequest",
     "SearchAllIamPoliciesResponse",
     "SearchAllResourcesRequest",
     "SearchAllResourcesResponse",
+    "TableFieldSchema",
+    "TableSchema",
     "UpdateFeedRequest",
     "UpdateSavedQueryRequest",
     "ContentType",
